@@ -15,14 +15,14 @@ class PHP_CodeCoverage_Report_XML_Tests
 {
     private $contextNode;
 
-    private $codeMap = array(
+    private $codeMap = [
         0 => 'PASSED',     // PHPUnit_Runner_BaseTestRunner::STATUS_PASSED
         1 => 'SKIPPED',    // PHPUnit_Runner_BaseTestRunner::STATUS_SKIPPED
         2 => 'INCOMPLETE', // PHPUnit_Runner_BaseTestRunner::STATUS_INCOMPLETE
         3 => 'FAILURE',    // PHPUnit_Runner_BaseTestRunner::STATUS_FAILURE
         4 => 'ERROR',      // PHPUnit_Runner_BaseTestRunner::STATUS_ERROR
         5 => 'RISKY'       // PHPUnit_Runner_BaseTestRunner::STATUS_RISKY
-    );
+    ];
 
     public function __construct(DOMElement $context)
     {
@@ -41,6 +41,5 @@ class PHP_CodeCoverage_Report_XML_Tests
         $node->setAttribute('size', $result['size']);
         $node->setAttribute('result', (int) $result['status']);
         $node->setAttribute('status', $this->codeMap[(int) $result['status']]);
-
     }
 }
